caellion-python-commons: Package Functions

caellion-python-commons

### - b -

- branch : version-check
- bump_by : version-check
- bump_major_term : version-check
- bump_minor_term : version-check

### - c -

- classname : parse-tests
- commitid : version-check
- commits : version-check
- contents : version-check

### - d -

- describe : version-check
- dsplit : version-check

### - e -

- encoding : parse-tests

### - f -

- file : version-check
- final_version : version-check

### - i -

- invalid_set_version : version-check
- is_initial : version-check

### - m -

- major : version-check
- major_ : version-check
- major_new : version-check
- minor : version-check
- minor_ : version-check
- minor_new : version-check

### - p -

- patch : version-check
- patch_ : version-check
- patch_new : version-check

### - r -

- root : parse-tests

### - s -

- set_version_term : version-check
- splits : version-check

### - t -

- TEST_DATA_PATH : tests.test_hashing_file_hashing
- TEST_PARAMETERIZED_LIST : tests.test_hashing_file_hashing
- tree : parse-tests

### - v -

- version : version-check
- version_short : version-check
- version_split : version-check
- version_tag : version-check
- vsubs : version-check

### - x -

- xml_declaration : parse-tests